@@ -13,6 +13,7 @@ Created by Celia Oakley on 2013-10-31.
 
 from .base import TMDB
 
+
 class Discover(TMDB):
     """
     Discover functionality.
@@ -34,7 +35,7 @@ class Discover(TMDB):
         Discover also supports a nice list of sort options. See below for all
         of the available options.
 
-        Please note, when using certification \ certification.lte you must also
+        Please note, when using certification / certification.lte you must also
         specify certification_country. These two parameters work together in
         order to filter the results. You can only filter results with the
         countries we have added to our certifications list.
@@ -50,64 +51,64 @@ class Discover(TMDB):
         separated. Comma's are treated like an AND and query while pipe's are
         an OR.
 
-        Some examples of what can be done with discover can be found at 
+        Some examples of what can be done with discover can be found at
         https://www.themoviedb.org/documentation/api/discover.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
             language: (optional) ISO 639-1 code.
-            sort_by: (optional) Available options are 'vote_average.desc', 
+            sort_by: (optional) Available options are 'vote_average.desc',
                      'vote_average.asc', 'release_date.desc', 'release_date.asc'
                      'popularity.desc', 'popularity.asc'.
-            include_adult: (optional) Toggle the inclusion of adult titles. 
+            include_adult: (optional) Toggle the inclusion of adult titles.
                            Expected value is a boolean, True or False.
             year: (optional) Filter the results release dates to matches that
                   include this value. Expected value is a year.
-            primary_release_year: (optional) Filter the results so that 
-                                  only the primary release date year has 
+            primary_release_year: (optional) Filter the results so that
+                                  only the primary release date year has
                                   this value.  Expected value is a year.
-            vote_count.gte or vote_count_gte: (optional) Only include movies 
-                            that are equal to, or have a vote count higher 
+            vote_count.gte or vote_count_gte: (optional) Only include movies
+                            that are equal to, or have a vote count higher
                             than this value.  Expected value is an integer.
-            vote_average.gte or vote_average_gte: (optional) Only include 
-                              movies that are equal to, or have a higher 
-                              average rating than this value.  Expected value 
+            vote_average.gte or vote_average_gte: (optional) Only include
+                              movies that are equal to, or have a higher
+                              average rating than this value.  Expected value
                               is a float.
-            with_genres: (optional) Only include movies with the specified 
-                         genres.  Expected value is an integer (the id of 
-                         a genre).  Multiple values can be specified. 
-                         Comma separated indicates an 'AND' query, while 
+            with_genres: (optional) Only include movies with the specified
+                         genres.  Expected value is an integer (the id of
+                         a genre).  Multiple values can be specified.
+                         Comma separated indicates an 'AND' query, while
                          a pipe (|) separated value indicates an 'OR'.
-            release_date.gte or release_date_gte: (optional) The minimum 
-                              release to include.  Expected format is 
+            release_date.gte or release_date_gte: (optional) The minimum
+                              release to include.  Expected format is
                               'YYYY-MM-DD'.
-            releaste_date.lte or release_date_lte: (optional) The maximum 
-                              release to include.  Expected format is 
+            releaste_date.lte or release_date_lte: (optional) The maximum
+                              release to include.  Expected format is
                               'YYYY-MM-DD'.
             certification_country: (optional) Only include movies with
                                    certifications for a specific country. When
                                    this value is specified, 'certification.lte'
                                    is required. An ISO 3166-1 is expected.
-            certification.lte or certification_lte: (optional) Only include 
-                               movies with this certification and lower. 
-                               Expected value is a valid certification for 
+            certification.lte or certification_lte: (optional) Only include
+                               movies with this certification and lower.
+                               Expected value is a valid certification for
                                the specified 'certification_country'.
-            with_companies: (optional) Filter movies to include a specific 
-                            company.  Expected value is an integer (the id 
-                            of a company).  They can be comma separated 
+            with_companies: (optional) Filter movies to include a specific
+                            company.  Expected value is an integer (the id
+                            of a company).  They can be comma separated
                             to indicate an 'AND' query.
-          
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
-        # Periods are not allowed in keyword arguments but several API 
+        # Periods are not allowed in keyword arguments but several API
         # arguments contain periods. See both usages in tests/test_discover.py.
-        for param in kwargs:
+        for param in dict(kwargs):
             if '_lte' in param:
                 kwargs[param.replace('_lte', '.lte')] = kwargs.pop(param)
             if '_gte' in param:
                 kwargs[param.replace('_gte', '.gte')] = kwargs.pop(param)
-        
+
         path = self._get_path('movie')
 
         response = self._GET(path, kwargs)
@@ -127,52 +128,52 @@ class Discover(TMDB):
         an OR.
 
         Some examples of what can be done with discover can be found at
-        https://www.themoviedb.org/documentation/api/discover. 
+        https://www.themoviedb.org/documentation/api/discover.
 
         Args:
             page: (optional) Minimum 1, maximum 1000.
             language: (optional) ISO 639-1 code.
-            sort_by: (optional) Available options are 'vote_average.desc', 
-                     'vote_average.asc', 'first_air_date.desc', 
+            sort_by: (optional) Available options are 'vote_average.desc',
+                     'vote_average.asc', 'first_air_date.desc',
                      'first_air_date.asc', 'popularity.desc', 'popularity.asc'
-            first_air_year: (optional) Filter the results release dates to 
-                            matches that include this value. Expected value 
+            first_air_year: (optional) Filter the results release dates to
+                            matches that include this value. Expected value
                             is a year.
-            vote_count.gte or vote_count_gte: (optional) Only include TV shows 
+            vote_count.gte or vote_count_gte: (optional) Only include TV shows
                             that are equal to,
                             or have vote count higher than this value. Expected
                             value is an integer.
-            vote_average.gte or vote_average_gte: (optional) Only include TV 
-                              shows that are equal 
-                              to, or have a higher average rating than this 
+            vote_average.gte or vote_average_gte: (optional) Only include TV
+                              shows that are equal
+                              to, or have a higher average rating than this
                               value.  Expected value is a float.
-            with_genres: (optional) Only include TV shows with the specified 
-                         genres. Expected value is an integer (the id of a 
-                         genre).  Multiple valued can be specified. Comma 
-                         separated indicates an 'AND' query, while a 
+            with_genres: (optional) Only include TV shows with the specified
+                         genres. Expected value is an integer (the id of a
+                         genre).  Multiple valued can be specified. Comma
+                         separated indicates an 'AND' query, while a
                          pipe (|) separated value indicates an 'OR'.
-            with_networks: (optional) Filter TV shows to include a specific 
+            with_networks: (optional) Filter TV shows to include a specific
                            network. Expected value is an integer (the id of a
                            network).  They can be comma separated to indicate an
                            'AND' query.
-            first_air_date.gte or first_air_date_gte: (optional) The minimum 
-                                release to include. 
+            first_air_date.gte or first_air_date_gte: (optional) The minimum
+                                release to include.
                                 Expected format is 'YYYY-MM-DD'.
-            first_air_date.lte or first_air_date_lte: (optional) The maximum 
-                                release to include. 
+            first_air_date.lte or first_air_date_lte: (optional) The maximum
+                                release to include.
                                 Expected format is 'YYYY-MM-DD'.
-          
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
-        # Periods are not allowed in keyword arguments but several API 
+        # Periods are not allowed in keyword arguments but several API
         # arguments contain periods. See both usages in tests/test_discover.py.
-        for param in kwargs:
+        for param in dict(kwargs):
             if '_lte' in param:
                 kwargs[param.replace('_lte', '.lte')] = kwargs.pop(param)
             if '_gte' in param:
                 kwargs[param.replace('_gte', '.gte')] = kwargs.pop(param)
-        
+
         path = self._get_path('tv')
 
         response = self._GET(path, kwargs)
